@@ -1,7 +1,7 @@
 /*
  * This file is part of Bino, a 3D video player.
  *
- * Copyright (C) 2022, 2023, 2024
+ * Copyright (C) 2022, 2023, 2024, 2025
  * Martin Lambers <marlam@marlam.de>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -33,9 +33,7 @@
 #include <QComboBox>
 #include <QActionGroup>
 #include <QMimeData>
-#if (QT_VERSION >= QT_VERSION_CHECK(6, 6, 0))
-# include <QWindowCapture>
-#endif
+#include <QWindowCapture>
 
 #include "gui.hpp"
 #include "playlist.hpp"
@@ -60,9 +58,9 @@ void Gui::addBinoAction(QAction* action, QMenu* menu)
 
 static Gui* GuiSingleton = nullptr;
 
-Gui::Gui(OutputMode outputMode, bool fullscreen) :
+Gui::Gui(OutputMode outputMode, float surroundVerticalFOV, bool fullscreen) :
     QMainWindow(),
-    _widget(new Widget(outputMode, this)),
+    _widget(new Widget(outputMode, surroundVerticalFOV, this)),
     _contextMenu(new QMenu(this))
 {
     setWindowTitle("Bino");
@@ -442,6 +440,11 @@ Gui::Gui(OutputMode outputMode, bool fullscreen) :
     _viewToggleSwapEyesAction->setCheckable(true);
     connect(_viewToggleSwapEyesAction, SIGNAL(triggered()), this, SLOT(viewToggleSwapEyes()));
     addBinoAction(_viewToggleSwapEyesAction, viewMenu);
+    viewMenu->addSeparator();
+    _viewResetSurroundAction = new QAction(tr("Reset surround view"), this);
+    _viewResetSurroundAction->setShortcuts({ Qt::Key_Z });
+    connect(_viewResetSurroundAction, SIGNAL(triggered()), this, SLOT(viewResetSurround()));
+    addBinoAction(_viewResetSurroundAction, viewMenu);
 
     QMenu* helpMenu = addBinoMenu(tr("&Help"));
     QAction* helpAboutAction = new QAction(tr("&About..."), this);
@@ -538,12 +541,8 @@ void Gui::fileOpenCamera()
     QList<QAudioDevice> audioOutputDevices = QMediaDevices::audioOutputs();
     QList<QAudioDevice> audioInputDevices = QMediaDevices::audioInputs();
     QList<QCameraDevice> videoInputDevices = QMediaDevices::videoInputs();
-#if (QT_VERSION >= QT_VERSION_CHECK(6, 5, 0))
     QList<QScreen*> screenInputDevices = QGuiApplication::screens();
-#endif
-#if (QT_VERSION >= QT_VERSION_CHECK(6, 6, 0))
     QList<QCapturableWindow> windowInputDevices = QWindowCapture::capturableWindows();
-#endif
     QGuiApplication::restoreOverrideCursor();
 
     QDialog *dialog = new QDialog(this);
@@ -557,39 +556,25 @@ void Gui::fileOpenCamera()
 
     QRadioButton *screenBtn = new QRadioButton(tr("Screen Input:"));
     QComboBox* screenBox = new QComboBox;
-#if (QT_VERSION >= QT_VERSION_CHECK(6, 5, 0))
     for (int i = 0; i < screenInputDevices.size(); i++)
         screenBox->addItem(screenInputDevices[i]->name());
-#endif
 
     QRadioButton *windowBtn = new QRadioButton(tr("Window Input:"));
     QComboBox* windowBox = new QComboBox;
-#if (QT_VERSION >= QT_VERSION_CHECK(6, 6, 0))
     for (int i = 0; i < windowInputDevices.size(); i++)
         windowBox->addItem(windowInputDevices[i].description());
-#endif
 
     videoBtn->setChecked(true);
     screenBtn->setChecked(false);
     windowBtn->setChecked(false);
-#if (QT_VERSION >= QT_VERSION_CHECK(6, 5, 0))
     if (screenInputDevices.size() == 0) {
         screenBtn->setEnabled(false);
         screenBox->setEnabled(false);
     }
-#else
-    screenBtn->setEnabled(false);
-    screenBox->setEnabled(false);
-#endif
-#if (QT_VERSION >= QT_VERSION_CHECK(6, 6, 0))
     if (windowInputDevices.size() == 0) {
         windowBtn->setEnabled(false);
         windowBox->setEnabled(false);
     }
-#else
-    windowBtn->setEnabled(false);
-    windowBox->setEnabled(false);
-#endif
 
     QLabel *audioLabel = new QLabel(tr("Audio Input:"));
     QComboBox* audioBox = new QComboBox;
@@ -631,23 +616,19 @@ void Gui::fileOpenCamera()
                     ? videoInputDevices[videoInputDeviceIndex]
                     : QMediaDevices::defaultVideoInput());
         } else if (screenBtn->isChecked()) {
-#if (QT_VERSION >= QT_VERSION_CHECK(6, 5, 0))
             int screenInputDeviceIndex = screenBox->currentIndex();
             Bino::instance()->startCaptureModeScreen(audioInputDeviceIndex >= -1,
                     audioInputDeviceIndex >= 0
                     ? audioInputDevices[audioInputDeviceIndex]
                     : QMediaDevices::defaultAudioInput(),
                     screenInputDevices[screenInputDeviceIndex]);
-#endif
         } else if (windowBtn->isChecked()) {
-#if (QT_VERSION >= QT_VERSION_CHECK(6, 6, 0))
             int windowInputDeviceIndex = windowBox->currentIndex();
             Bino::instance()->startCaptureModeWindow(audioInputDeviceIndex >= -1,
                     audioInputDeviceIndex >= 0
                     ? audioInputDevices[audioInputDeviceIndex]
                     : QMediaDevices::defaultAudioInput(),
                     windowInputDevices[windowInputDeviceIndex]);
-#endif
         }
     }
 }
@@ -839,6 +820,12 @@ void Gui::viewToggleSwapEyes()
     _widget->update();
 }
 
+void Gui::viewResetSurround()
+{
+    _widget->resetSurroundView();
+    _widget->update();
+}
+
 void Gui::helpAbout()
 {
     QMessageBox::about(this, tr("About Bino"),
@@ -938,6 +925,7 @@ void Gui::updateActions()
     }
 
     SurroundMode surroundMode = Bino::instance()->assumeSurroundMode();
+    _viewResetSurroundAction->setEnabled(surroundMode != Surround_Off);
     for (int i = 0; i < _3dSurroundActionGroup->actions().size(); i++) {
         QAction* a = _3dSurroundActionGroup->actions()[i];
         a->setChecked(a->data().toInt() == int(surroundMode));
@@ -980,6 +968,12 @@ void Gui::setOutputMode(OutputMode mode)
     _widget->update();
 }
 
+void Gui::setSurroundVerticalFieldOfView(float vfov)
+{
+    _widget->setSurroundVerticalFieldOfView(vfov);
+    _widget->update();
+}
+
 void Gui::setFullscreen(bool f)
 {
     if (f && !(windowState() & Qt::WindowFullScreen)) {
