@@ -1,7 +1,7 @@
 /*
  * This file is part of Bino, a 3D video player.
  *
- * Copyright (C) 2022
+ * Copyright (C) 2022, 2023, 2024
  * Martin Lambers <marlam@marlam.de>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -26,6 +26,13 @@
 #include "tools.hpp"
 
 
+bool IsOpenGLES;
+void initializeIsOpenGLES(const QSurfaceFormat& format)
+{
+    IsOpenGLES = (QOpenGLContext::openGLModuleType() == QOpenGLContext::LibGLES
+            || format.renderableType() == QSurfaceFormat::OpenGLES);
+}
+
 QString readFile(const char* fileName)
 {
     QFile f(fileName);
@@ -44,3 +51,17 @@ const char* getOpenGLString(QOpenGLExtraFunctions* gl, GLenum p)
 {
     return reinterpret_cast<const char*>(gl->glGetString(p));
 }
+
+QString getExtension(const QString& fileName)
+{
+    QString extension;
+    int lastDot = fileName.lastIndexOf('.');
+    if (lastDot > 0)
+        extension = (fileName.right(fileName.length() - lastDot - 1)).toLower();
+    return extension;
+}
+
+QString getExtension(const QUrl& url)
+{
+    return getExtension(url.fileName());
+}
