@@ -40,7 +40,7 @@
 
 static const QSize SizeBase(16, 9);
 
-Widget::Widget(OutputMode outputMode, QWidget* parent) :
+Widget::Widget(OutputMode outputMode, float surroundVerticalFOV, QWidget* parent) :
     QOpenGLWidget(parent),
     _sizeHint(0.5f * SizeBase),
     _outputMode(outputMode),
@@ -52,6 +52,8 @@ Widget::Widget(OutputMode outputMode, QWidget* parent) :
     _surroundHorizontalAngleCurrent(0.0f),
     _surroundVerticalAngleCurrent(0.0f)
 {
+    setSurroundVerticalFieldOfView(surroundVerticalFOV);
+    _surroundVerticalFOVDefault = _surroundVerticalFOV; // to make sure clamping was applied
     setUpdateBehavior(QOpenGLWidget::PartialUpdate);
     setMouseTracking(true);
     setMinimumSize(8, 8);
@@ -79,6 +81,20 @@ void Widget::setOutputMode(enum OutputMode mode)
     _outputMode = mode;
 }
 
+void Widget::setSurroundVerticalFieldOfView(float vfov)
+{
+    _surroundVerticalFOV = qBound(5.0f, vfov, 115.0f);
+}
+
+void Widget::resetSurroundView()
+{
+    _surroundVerticalFOV = _surroundVerticalFOVDefault;
+    _surroundHorizontalAngleBase = 0.0f;
+    _surroundVerticalAngleBase = 0.0f;
+    _surroundHorizontalAngleCurrent = 0.0f;
+    _surroundVerticalAngleCurrent = 0.0f;
+}
+
 QSize Widget::sizeHint() const
 {
     return _sizeHint;
@@ -105,12 +121,18 @@ void Widget::initializeGL()
     QString variantString = IsOpenGLES ? "OpenGL ES" : "OpenGL";
     if (!IsOpenGLES)
         variantString += isCoreProfile ? " core profile" : " compatibility profile";
+    GLint maxTexSize, maxFBWidth, maxFBHeight;
+    glGetIntegerv(GL_MAX_TEXTURE_SIZE, &maxTexSize);
+    glGetIntegerv(GL_MAX_FRAMEBUFFER_WIDTH, &maxFBWidth);
+    glGetIntegerv(GL_MAX_FRAMEBUFFER_HEIGHT, &maxFBHeight);
     LOG_INFO("OpenGL Variant:      %s", qPrintable(variantString));
     LOG_INFO("OpenGL Version:      %s", getOpenGLString(this, GL_VERSION));
     LOG_INFO("OpenGL GLSL Version: %s", getOpenGLString(this, GL_SHADING_LANGUAGE_VERSION));
     LOG_INFO("OpenGL Vendor:       %s", getOpenGLString(this, GL_VENDOR));
     LOG_INFO("OpenGL Renderer:     %s", getOpenGLString(this, GL_RENDERER));
     LOG_INFO("OpenGL AnisoTexFilt: %s", haveAnisotropicFiltering ? "yes" : "no");
+    LOG_INFO("OpenGL Max Tex Size: %d", maxTexSize);
+    LOG_INFO("OpenGL Max FB Size:  %dx%d", maxFBWidth, maxFBHeight);
 
     // View textures
     glGenTextures(2, _viewTex);
@@ -281,9 +303,9 @@ void Widget::paintGL()
         QMatrix4x4 orientationMatrix;
         QMatrix4x4 viewMatrix;
         if (Bino::instance()->assumeSurroundMode() != Surround_Off) {
-            float verticalVieldOfView = qDegreesToRadians(50.0f);
-            float aspectRatio = float(width) / height;
-            float top = qTan(verticalVieldOfView * 0.5f);
+            float verticalFieldOfView = qDegreesToRadians(_surroundVerticalFOV);
+            float aspectRatio = 2.0f; // always 2:1 for surround video!
+            float top = qTan(verticalFieldOfView * 0.5f);
             float bottom = -top;
             float right = top * aspectRatio;
             float left = -right;
@@ -414,6 +436,12 @@ void Widget::mouseMoveEvent(QMouseEvent* e)
     }
 }
 
+void Widget::wheelEvent(QWheelEvent* e)
+{
+    setSurroundVerticalFieldOfView(_surroundVerticalFOV - e->angleDelta().y() / 120.0f);
+    update();
+}
+
 void Widget::mediaChanged(PlaylistEntry)
 {
     _inSurroundMovement = false;
